@@ -1,3 +1,4 @@
+import traceback
 from ..classes.Color import Color
 from ..classes.Log import logTime
 from ..classes.socket.events.events import Events
@@ -166,12 +167,11 @@ class Socket:
                 print(f"{Color.WARNING}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()}", incomming, f" was not fetched!{Color.ENDC}")
         
         def on_error(ws, what_failed):
-            print(f"{Color.FAIL}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()} Error with websockets \nClose code:", what_failed, f"{Color.ENDC}")
-            ws.close()
+            print(f"{Color.FAIL}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()} Error with websockets \n The error:", what_failed, f"{Color.ENDC}")
+            traceback.print_exc()
 
         def on_open(ws):
             print(f"{Color.OKGREEN}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()} Connected with the websockets!{Color.ENDC}")
-            ws.close()
 
         def on_close(ws, close_status_code, close_msg):
             print(f"{Color.WARNING}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()} Websockets closed!\nClose code:", close_status_code,"  Close msg:", close_msg, f"{Color.ENDC}")
